@@ -2171,7 +2171,7 @@ status ObjectFile<T>::Read_ObjectFile_Header(void)
    {
       status		result		= OK;
 
-      if (itsheader.Read_ObjectFile_Header(itsfile, itshandle,
+      if (itsheader.Read_ObjectFile_Header(itsfile, itsfilehandle,
          itsuserheader) == ERROR)
          {
 	    /* Could not read header.					*/
